# -*- coding: UTF-8 -*-
#   icd_part_rename.py  2023.11.25  kita

#!! 外部パーツの名前を変更して保存する

# ICADを操るためのおまじない
import clr
clr.AddReference('sxnet')
from sxnet import *

import tkinter as tk
#from tkinter import *
#from tkinter import messagebox
from tkinter import ttk

import numpy as np
import icd_module as imd
import my_module as mmd
import my_tk as mtk
import os
from time import sleep
import sys
import subprocess
import shutil
import re       # 文字列置換(正規表現使用)

try:
    from screeninfo import get_monitors
    n_moniter= len(get_monitors())
except:
    #ss_msg1= 'screeninfo がインストールされていません。\n'
    #ss_msg2= 'PSより pip install screeninfo でインストールできます'
    #ss_msg= ss_msg1+ ss_msg2
    #mtk.warning(ss_msg)
    n_moniter= 0

# Global定数、変数
my_fn= os.path.basename(__file__)       # icd_*.py
icad_path= SxSys.getDir().replace('\\','/')+ '/'
my_save_fn= icad_path+ my_fn.replace('.py','.dat')    # c:\icadsx\....dat
gomi_dir= 'c:/ICADSX/gomi/'     # ゴミ箱

#パーツ辞書
part_dic= {}   # part_dic[name0]= [part, name1, cmnt0, cmnt1, fp_fn0]
                       #[元図番]= [part,新図番,元品名,新品名,元ファイル名]                                 
#Editorの設定  editor   エディター
edit_fn = 'editor.ini'
if os.path.exists(edit_fn):      # fnが存在するなら
    with open(edit_fn, 'r') as fp:
        for line in fp.readlines():
            if line.find('#') > -1: continue # #が含まれてるなら
            line = line.rstrip()    # 行末の改行を削除
            tmp = line.split(',')
            if tmp[0] == 'editor':
                editor = tmp[1]
else:
    editor = 'notepad'



# File編集ボタン
def push_edit():
    fp_fn= entry[3].get()
    cmd= '%s %s' % (editor, fp_fn)
    result = subprocess.Popen(cmd,shell=False)


# 実行ボタン
def push_exe():
    #global part_dic
    #part_dic= {}    # 辞書の初期化
    SxSys.setDim(True) #3Dに切り替え 3D切り替え
    ext_part_list= get_ext_part()
    #if ext_part_list== None :
    #    mtk.information('対象パーツがありません。\n処理を終了します')
    #    return
    if len(ext_part_list)== 0: 
        mtk.information('対象パーツがありません。\n処理を終了します')
        return
    if v_rb1.get()== 0: # append Rename
        part_dic= append_rename(ext_part_list)
    
    elif v_rb1.get()== 1: # 置換Rename
        part_dic= replace_rename(ext_part_list)
        #(part_list, part_name_list, del_file_list)= replace_rename(ext_part_list)
    elif v_rb1.get()== 2: # Csv編集Rename
        part_dic= csv_rename(ext_part_list)
    #print(part_dic.keys())   
    #return      

    if len(part_dic)== 0:
        mtk.information('対象パーツがありません。\n処理を終了します')
        return
    else:
        # パーツ名変更本体
        cnt= rename_core(part_dic)
        # 後処理 元図削除等
        if cnt== 0:
            mtk.warning('Rename対象ファイルはありませんでした')
        else:
            ss= '%d 個のファイルの後処理をします' % cnt
            ssd= '(保存、アクセス権開放、元図削除、等)'
            if mtk.question_oc(ss, ssd):
                post_process(part_dic)
    


def get_ext_part():    # 選択パーツ内の外部パーツを選択
    #part_dic= {}    # 辞書の初期化
    part_list= []   # 外部パーツリスト
    tmp_list= []  # 重複削除用 
    ent_list = SxSys.getEntList(SxSys.ENTMODE_PART) # マウスドラッグ & マウスピック
    if ent_list== None:
        return part_list
    for ent in ent_list:
        type_num= ent.Type
        if type_num== 204:  # パーツ
            inf= ent.getInfDetail()
            name0= inf.name
            cmnt0= inf.comment
            #path0= (inf.path).replace('\\','/')  # 参照図面格納フォルダ
            #fp_fn0= '%s/%s.icd' % (path0, inf.ref_model_name) # パーツ参照図面名 Full_path
            if not inf.is_external: # 内部パーツを除外
                ss= ('%s %s\nは内部パーツです') % (name0, cmnt0)
                mtk.warning(ss)
                continue
            # 重複削除
            if name0 in tmp_list:
                continue
            #lisstに追加
            part_list.append(ent)
            # 辞書に追加
            #part_dic[name0]= [ent, name0, cmnt0, cmnt0, fp_fn0]
            # 
            tmp_list.append(name0)
            #print('get_ext_part() : %s' % name0)  ###
    return part_list 


# Rename内容の確認 Editorで開くEditor Check
def rename_check(part_dic):
    #replace_word0= entry[1].get()   # 001.$
    #replace_word1= entry[2].get()   # 0020     
    fp_fn_csv= entry[3].get()   # c:/ICADSX/Rename.csv

    ss= '# 元図番(パーツ名),新図番, 元品名(コメント)\n'  # 書き出し文字列
    i= 0
    for key in part_dic:
        name0= key
        name1= part_dic[key][1]
        cmnt0= part_dic[key][2]
        cmnt1= part_dic[key][3]
        tmp= '%14s, %14s, %14s, %14s\n' % (name0, name1, cmnt0, cmnt1)
        ss= ss+ tmp
        i+= 1

    ss= ss+ '\n# ※元図番を変更、抹消はしないでください。\n'
    ss= ss+ '# ※変更不要となった場合は新図番(パーツ名)と品名(コメント)だけを削除してください。\n'
    ss= ss+ '# ※新図番は編集された図番が採用されます。\n'

    #print(ss)   
    with open(fp_fn_csv, 'w') as fp:
        fp.write(ss)
    # Fileを開いて編集
    cmd= '%s %s' % (editor, fp_fn_csv)
    #result = subprocess.Popen(cmd,shell=False)
    result= subprocess.Popen(cmd,shell=True)
    result.wait()   # subprocess 終了確認

    part_dic= get_part_for_csv(part_dic, fp_fn_csv)
    return part_dic

# 編集ファイルよりRename情報読み込み　return part_dic
def get_part_for_csv(part_dic, fp_fn_csv):
    with open(fp_fn_csv, 'r') as fp:
        lines= fp.readlines()

    #part_dic= {} # 初期化
    for line in lines:
        if line.find('#') > -1 or len(line) < 3: # #行、空白行除外
            continue
        line = line.rstrip()    # 行末の改行削除
        line= line.replace(' ', '')   # スペース削除
        arr= line.split(',')
        #print('line= %s' % line)    
        name0= arr[0]
        part= part_dic[name0][0]
        fp_fn0= part_dic[name0][4]
        name1= arr[1]
        cmnt0= arr[2]
        cmnt1= arr[3]
        part_dic[name0]=[part, name1, cmnt0, cmnt1, fp_fn0]

    return part_dic


#--------------------------------    
# 追加 Rename
#--------------------------------    
def append_rename(part_list):  # 追加リネーム
    part_dic= {}    # 辞書初期化
    ad_ss= entry[0].get()       # tmp* or *tmp    
    if not ad_ss.count('*'):    # [*]がないなら
        ad_ss= ad_ss+'*'        # tmp*

    for part in part_list:
        inf = part.getInfDetail()  # パーツ詳細情報
        name0= inf.name        # パーツ名  810210110010
        #if v_chk[0].get:　    # File名-1桁
        #    filename0= name0[:-1]      # 81021011001
        #else:
        #    filename0= name0           # 810210110010    
        filename0= inf.ref_model_name   # 81021011001 (or 810210110010) 
        cmnt0= inf.comment     # コメント   
        path0= (inf.path).replace('\\','/')  # 参照図面格納フォルダ s:/
        fp_fn0= '%s/%s.icd' % (path0, inf.ref_model_name) # s:/81021011001 

        name1= ad_ss.replace('*',name0)  # tmp810210110010 or 810210110010tmp
        filename1= ad_ss.replace('*',filename0)  # tmp81021011001 or 81021011001tmp
        
        fp_fn1= '%s/%s.icd' % (path0, filename1)   # s:/tmp81021011001.icd or s:/81021011001tmp.icd
        #print(fp_fn0, fp_fn1)
        if os.path.exists(fp_fn1):  # 新図番ファイルが既存
            #####################################
            tmp0= ad_ss.replace('*','')         # tmp
            tmp1= ad_ss.replace('*', '_')       # tmp_ or _tmp 
            fp_fn2= fp_fn1.replace(tmp0, tmp1)  # s:/tmp_81021011001.icd  or s:/81021011001_tmp.icd
            name2= name1.replace(tmp0, tmp1)    # tmp_81021011001 or 81021011001_tmp
            print(name2, fp_fn2)  

            ss= '%s が既に存在します。%s に変更しますか?' % (fp_fn1, fp_fn2)
            ssd= '(パーツ名 %s => %s' % (name1, name2) 
            if mtk.question_yn(ss,ssd):
                part_dic[name0]= [part, name2, cmnt0, cmnt0, fp_fn2]
            else:
                mtk.warning('%s のリネームをスキップします' % name0)
                continue
        else:
            part_dic[name0]= [part, name1, cmnt0, cmnt0, fp_fn0]

    if v_chk[4].get() and len(part_dic)!= 0:    # 内容チェック、再編集
         part_dic= rename_check(part_dic)
        
    return part_dic

#--------------------------------    
# 置換 Rename
#--------------------------------    
def replace_rename(part_list):   # 置換Rename 既に外部パーツ
    part_dic= {}     # 辞書初期化
    replace_word0= entry[1].get()   # 001.$ 
    replace_word1= entry[2].get()   # 0020 
    fp_fn_csv= entry[3].get()   # c:/ICADSX/Rename.csv
    part_name_list= []      # 重複削除用

    for part in part_list:
        inf= part.getInfDetail()  # パーツ詳細情報取得
        name0= inf.name        # パーツ名
        cmnt0= inf.comment     # パーツコメント
        path0= (inf.path).replace('\\','/')  # 参照図面格納フォルダ
        fp_fn0= '%s/%s.icd' % (path0, inf.ref_model_name) # パーツ参照図面名 Full_path
        if re.search(replace_word0, name0)!= None: # name0内にreplace_word0 が含まれる
            # 重複削除
            if name0 in part_name_list:
                continue
            
            name1= re.sub(replace_word0,replace_word1, name0)  # 810014120011=>810014120020

            if v_chk[0].get:    # File名-1桁
                filename1= name1[:-1]
            else:
                filename1= name1
            fp_fn1= '%s/%s.icd' % (path0, filename1)   # 新しいファイル名

            if os.path.exists(fp_fn1):  # 新図番ファイルが既存
                mtk.warning('%s が既に存在します。リネームをスキップします' % name0)
                continue
            else:
                part_dic[name0]= [part, name1, cmnt0, cmnt0, fp_fn0]
                part_name_list.append(name0)

    if v_chk[4].get and len(part_dic)!= 0:    # 内容チェック、再編集
         part_dic= rename_check(part_dic)
    return part_dic        


#--------------------------------    
# Csv編集 Rename
#--------------------------------    
def csv_rename(part_list):  # Csv編集 Rename 
    part_dic= {}    # 辞書初期化
    for part in part_list:
        inf = part.getInfDetail()  # パーツ詳細情報
        name0= inf.name        # パーツ名
        cmnt0= inf.comment     # コメント 
        path0= (inf.path).replace('\\','/')  # 参照図面格納フォルダ
        fp_fn0= '%s/%s.icd' % (path0, inf.ref_model_name) # パーツ参照図面名 Full_path
        name1= name0 
        fp_fn1= '%s/%s.icd' % (path0, name1)        # 新しいファイル名
        part_dic[name0]= [part, name1, cmnt0, cmnt0, fp_fn0]

    part_dic= rename_check(part_dic)
        
    return part_dic

#--------------------------------    
# Part Rename 本体
#--------------------------------    
def rename_core(part_dic): # return cnt (Rename処理数)
    cnt= 0
    for key in part_dic:
        name0= key
        #print(name0)
        part= part_dic[key][0]
        name1= part_dic[key][1]
        cmnt0= part_dic[key][2]
        cmnt1= part_dic[key][3]
        fp_fn0= part_dic[key][4]
        
        inf= part.getInfDetail()  # パーツ詳細情報
        
        #if not inf.is_read_only: # 外部パーツのアクセス権がない
        #    mtk.information('アクセス権がないので取得します',name0)
        #    part.setAccess(False)    #パーツのアクセス権取得
            #part.setAccess(True)    #パーツのアクセス権解放
        if name0== name1 and cmnt0== cmnt1: # 同名、同コメントファイル
            mtk.warning('%s は変更カ所がありません' % name0)
            continue

        if v_chk[0].get:    # File名-1桁
            filename1= name1[:-1]
        else:
            filename1= name1

        # 外部パーツのパーツ名、ファイル名変更(黒文字）
        path0= (inf.path).replace('\\','/')  # 参照図面格納フォルダ
        fp_fn1= '%s/%s.icd' % (path0, filename1)
        if os.path.exists(fp_fn1):     # Fileが存在するなら
            pass
                
        # Rename 本体の本体
        change_all= v_chk[3].get()
        #print(name1, cmnt1, filename1, change_all)  
        try:
            part.setName(name1, cmnt1, filename1, change_all)
            # この段階でファイルは保存されている!!
            #################################################
            #if mtk.question_oc('%s を削除しますか?' % fp_fn1):
            #    os.remove(fp_fn1)    # 後でまとめて保存するので...
            cnt+= 1
        except Exception as e:
                ss= f"エラーが発生しました: {e}"
                mtk.warning(ss)
                ss= '%s を %sに置き換えますか?' % (name0, name1)    
                if mtk.question_yn(ss) :
                    file_part = SxFileModel(fp_fn1)
                    part.replace(file_part, change_all)    # 全ての同名パーツを置き換える
        #print('os.remove 実行')  
        #os.remove(fp_fn1)    # 後でまとめて保存するので...)

    #return (part1_list, fp_fn0_list) # 変更パーツリスト、変更前ファイル名リスト
    return cnt

# part_listの後処理
def post_process(part_dic):
    # 変更パーツ保存、Access権開放
    nn= len(part_dic)
    part_list= []; del_file_list=[]
    for key in part_dic:
        part_list.append(part_dic[key][0])
        del_file_list.append(part_dic[key][4])

    ss= '%d 個のパーツが変更されました。保存しますか？' % nn
    TF= mtk.question_yn(ss)
    if TF:
        model= SxModel.getActive()
        model.save()
        #model.savePart(None, False, False)      # 最上位パーツ保存 
        #model.savePart(part_list, True, True)  # 指定パーツ配下の編集された外部パーツファイルを保存
        #model.savePart(part_list, False, False) 

    if v_chk[2].get():  # Access権解放
        TF= mtk.question_yn('アクセス権を開放しますか？')
        for part in part_list:
            try:
                part.setAccess(True)    #パーツのアクセス権解放
            except Exception as e:
                ss= f"エラーが発生しました: {e}"
                mtk.warning(ss)

    if v_chk[1].get() and len(del_file_list)> 0:  # 元図削除check and list not 0
        if mtk.question_yn('元図を削除しますか？'):
            for fp_fn0 in del_file_list:
                ss= '%s を削除しますか？' % fp_fn0
                ssd= '(実際は %s へ移動します)' % gomi_dir 
                if mtk.question_yn(ss, ssd):
                    try:    # 同名ファイルが存在する場合のエラー処理
                        print(fp_fn0, gomi_dir)
                        shutil.move(fp_fn0, gomi_dir)
                    except: # '_'を付加して保存
                        mtk.information('同名ファイルがあるので「_」を付加して保存します。')
                        fn_ext= os.path.basename(fp_fn0)
                        (fn, ext) = os.path.splitext(fn_ext) # (test, dat) 拡張子抽出 拡張子を抽出
                        fn1= fn+ '_'+ ext 
                        print(fp_fn0, gomi_dir+fn1, ext)
                        shutil.move(fp_fn0, gomi_dir+ fn1)
        
def push_help():    # 開発Versionでも同じヘルプを開く
    (fn, ext) = os.path.splitext(my_fn)
    if fn[-1]== '_':
        fn= fn[:-1]
    cmd= '%s %s.txt' % (editor, fn)
    result = subprocess.Popen(cmd,shell=True)
    

def set_entry(idx, ss): # Entryに文字列を挿入
    entry[idx].delete(0,tk.END)
    entry[idx].insert(0,ss)

def set_entry2(ent, ss): # Entryに文字列を挿入
    ent.delete(0,tk.END)
    ent.insert(0,ss)


def set_data(): # *.datを読み込んで Entryその他に設定
    with open(my_save_fn, 'r') as fp:
        lines = fp.readlines()
    ie= 0; ichk= 0
    for line in lines:
        line = line.rstrip()    # 行末の改行削除
        if line.find('#') > -1:  # #が含まれてるなら
            continue

        tmp = line.split('= ')
        #print(tmp) #!!!!
        if line.find('entry') > -1: # Entry行
            if len(tmp) > 1:
                set_entry(ie, tmp[1])
            else: 
                set_entry(ie, ' ')   # 空なら
            ie+= 1
        elif line.find('v_rb') > -1: # RadioButton行
            v_rb1.set(int(tmp[1]))
        elif line.find('v_chk') > -1: # RadioButton行
            v_chk[ichk].set(tmp[1])
            ichk+= 1

def chk_col():  # CheckButtonの色変更
    for i in range(len(chk)):
        if v_chk[i].get()== 1:
            chk[i]['bg']= 'pink'
        else:
            chk[i]['bg']= 'white'

def rb1_clicked():
    if v_rb1.get()== 0 or v_rb1.get()== 1: # 追加Rename
        v_chk[1].set(False)   # 元図削除 Off
        chk_col() 

"""
def rb1_col():  # RadioButtonの色変更
    for i in range(len(rb1)):
        if v_rb1[i].get():
            rb1[i]['bg']= 'pink'
        else:
            rb1[i]['bg']= 'white'
"""

def save_data():    # Entry, CheckButton 設定値保存
    ss = ''
    for i in range(len(entry)):
        ss= ss + 'entry[%d]= %s\n' % (i, entry[i].get())
        #print(i, entry[i].get())

    ss= ss + 'v_rb1= %d\n' % (v_rb1.get())
    #print(v_rb1.get())
    
    for i in range(len(v_chk)):
        ss= ss+ 'v_chk[%d]= %s\n' % (i, v_chk[i].get())
        #print(i, v_chk[i].get())

    with open(my_save_fn,'w') as fp:
        fp.write(ss)

def on_closing():       # 終了時の処理
    save_data()
    ss_geom = root.geometry() 
    mmd.save_geometry(save_fn_geom, ss_geom)

    #print('\n   %s を終了しました\n' % tmp_fn)
    #print('\n   %s を終了しました\n' % my_fn)
    #mtk.information('%s を終了しました' % my_fn)

    if mtk.question_oc('%s を終了しますか？' % my_fn):
        root.destroy()
    else: return

#************************************
# ボタン等の部品配置
#************************************
nl = 8
root = tk.Tk()
root.attributes("-topmost", True)    # 常に前面に表示
root.configure(bg='RoyalBlue4')
root.title(my_fn)  #タイトル
save_fn_geom= my_fn.replace('.py', '.ini')
ss_geom= mmd.read_geometry(save_fn_geom)
if ss_geom== None or n_moniter== 1:
    ss_geom = '270x%d+1000+0' % (nl*28)

root.geometry(ss_geom)

btn_bcol = 'grey21'     #ボタン背景色
btn_tcol = 'white'      #ボタン文字色
label_bcol = 'khaki3'   #ラベル背景色
label_tcol = 'black'    #ラベル文字色
e_bcol = 'ivory2'       #Entry背景色

x0= 2; y0= 2
dx= 100; dy= 25
px= 2; py= 2
ie=0


# Frame1 
frame1 = tk.LabelFrame(root, text='外部パーツ名変更、保存', padx=px, pady=py,
        width=265, height=155,bg="RoyalBlue3",fg=btn_tcol) 
frame1.place(x=x0,y=y0)
entry= []; ie= 0
entry_txt= ['tmp*','001.$','0020','c:/ICADSX/Rename.csv']
ss1 = ['追加Rename','置換Rename','Csv編集Rnm']

v_rb1= tk.IntVar(frame1, value = 0)    #初期値設定
for i in range(len(ss1)):      # iには 0,1,2が入る
    rb1= tk.Radiobutton(frame1, text= ss1[i], value= i, variable= v_rb1, \
            bg= 'cyan',fg= 'black', command= rb1_clicked)
    #r= tk.Radiobutton(frame1, text= ss1[i], value= i, variable= v_rb1,fg= 'white', bg='RoyalBlue')
    #r= ttk.Radiobutton(frame1, text= ss1[i], value= i, variable= v_rb1)
    rb1.place(x= x0,y= y0+i*(dy-1))
#v_rb1.set(0)

entry.append(tk.Entry(frame1, width=12, justify="right",bg=e_bcol))
entry[ie].place(x=100, y= y0+0*dy)  # tmp*
set_entry(ie, entry_txt[ie]); ie+= 1

entry.append(tk.Entry(frame1, width=12, justify="right",bg=e_bcol))
entry[ie].place(x=100, y= y0+1*dy)  # 001.$
entry.append(tk.Entry(frame1, width=12, justify="right",bg=e_bcol))

set_entry(ie, entry_txt[ie]); ie+= 1
entry[ie].place(x=180, y= y0+1*dy)  # 0020
set_entry(ie, entry_txt[ie]); ie+= 1

#label = tk.Label(frame1,text='置換File名' ,bg=label_bcol)  # Labelの作成
#label.place(x=x0,y= y0+2*dy)

# 置換パーツ一覧ファイル名
entry.append(tk.Entry(frame1, width=25,justify="right",bg=e_bcol))
entry[ie].place(x=100, y= y0+2*dy)  # c:/ICADSX/Rename.csv
set_entry(ie, entry_txt[ie]); ie+= 1

# rootに配置
v_chk= []; chk=[]
# Naming Rule Check Button idx= 0
v_chk.append(tk.BooleanVar())   # 論理値型の変数 Instance
v_chk[-1].set(True)          # 初期値File名桁落ち 
chk.append(tk.Checkbutton(frame1,text='File名-1桁',variable=v_chk[-1], command= chk_col)) #, background='pink'))
chk[-1].place(x=x0,y=y0+3*dy)

# 元図削除 Check Button idx= 1
v_chk.append(tk.BooleanVar())   # 論理値型の変数 Instance
v_chk[-1].set(False)          # 初期値品名記入なし 
chk.append(tk.Checkbutton(frame1,text='元図削除',variable=v_chk[-1], command= chk_col))
chk[-1].place(x=x0+85,y=y0+3*dy)

# Access権開放　Check Button    idx= 2
v_chk.append(tk.BooleanVar())   # 論理値型の変数 Instance
v_chk[-1].set(False)          # 初期値品名記入なし 
chk.append(tk.Checkbutton(frame1,text='Acs権開放',variable=v_chk[-1], command= chk_col))
chk[-1].place(x=x0+165,y=y0+3*dy)

# 同名パーツ一括　Check Button  idx= 3
v_chk.append(tk.BooleanVar())   # 論理値型の変数 Instance
v_chk[-1].set(True)          # 初期値品名記入なし 
chk.append(tk.Checkbutton(frame1,text='同名一括',variable=v_chk[-1], command= chk_col))
chk[-1].place(x=x0,y=y0+4.2*dy)

# Rename内容のチェック Editor起動 Check Button idx= 4
v_chk.append(tk.BooleanVar())   # 論理値型の変数 Instance
v_chk[-1].set(True)          # 初期値品名記入なし 
chk.append(tk.Checkbutton(frame1,text='内容Check',variable=v_chk[-1], command= chk_col))
chk[-1].place(x=x0+85,y=y0+4.2*dy)

# 元図情報書出 Check Button idx= 5
v_chk.append(tk.BooleanVar())   # 論理値型の変数 Instance
v_chk[-1].set(False)          # 初期値品名記入なし 
chk.append(tk.Checkbutton(frame1,text='元図情報',variable=v_chk[-1], command= chk_col))
chk[-1].place(x=x0+175,y=y0+4.2*dy)
chk[-1]['state'] = 'disabled'

# ヘルプ Button
btn_help = tk.Button(root,text = 'ヘルプ',command= push_help,bg=btn_bcol,fg=btn_tcol) 
btn_help.place(x=x0+10,y=y0+6.5*dy)

# File編集 Button
btn_edit = tk.Button(root,text = 'csvFile閲覧',command= push_edit,bg=btn_bcol,fg=btn_tcol) 
btn_edit.place(x=x0+60,y=y0+6.5*dy)


# 外部パーツの名前を変えて保存実行
btn_exe = tk.Button(root,text = '実行',command = push_exe,bg='orange',fg='black') 
btn_exe.place(x=x0+220,y=y0+6.5*dy)

ss= '※「Esc」キーで選択キャンセル、@GOで確定します。'
label= tk.Label(root,text=ss ,bg=label_bcol)
label.place(x=x0+10, y=y0+7.8*dy)       # Labelの位置

#--------------------------------
#   起動時の処理
#--------------------------------
# icd_tenkaizu.datがあれば読み込んでパラメータセット
if os.path.exists(my_save_fn) == True:
    set_data()  # entry その他の値設定
    # CheckButtonの色変更
    chk_col()


# 終了時の処理
root.protocol("WM_DELETE_WINDOW", on_closing)
root.mainloop()
